"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.callBuiltinMethod = exports.checkAuthOfMethod = exports.normalizeBuiltinMethodName = exports.fallback2oldMethodName = exports.isBuiltinMethod = exports.isNewBuiltinName = exports.dbDefaultMethods = void 0;
/**
 * 数据源方法相关方法
 */
const weda_api_1 = require("../weda-api");
const database_1 = __importDefault(require("./database"));
const utils_1 = require("../utils");
var database_2 = require("./database");
Object.defineProperty(exports, "dbDefaultMethods", { enumerable: true, get: function () { return __importDefault(database_2).default; } });
const BUILTIN_METHOD_NAMES = ['create', 'delete', 'update', 'getItem', 'getList', 'getRecords'];
const BUILTIN_NAME_REG = /^weda\S+/;
/**
 * 是否使用的新的数据源内置方法命名
 */
function isNewBuiltinName(name) {
    return BUILTIN_NAME_REG.test(name);
}
exports.isNewBuiltinName = isNewBuiltinName;
/** 是否为内置云函数 */
function isBuiltinMethod(name) {
    return BUILTIN_NAME_REG.test(name) || BUILTIN_METHOD_NAMES.includes(name);
}
exports.isBuiltinMethod = isBuiltinMethod;
/**
 * 将数据源方法名称倒退回旧名称
 */
function fallback2oldMethodName(name) {
    const oldName = name.replace(/^weda([A-Z])/, ($0, $1) => $1.toLowerCase());
    // 的确为原来支持的内置方法才返回旧名称
    if (BUILTIN_METHOD_NAMES.includes(oldName))
        return oldName;
    return name;
}
exports.fallback2oldMethodName = fallback2oldMethodName;
/**
 * 标准化内置云函数名称, 无 weda 前缀的增加 weda 前缀
 */
function normalizeBuiltinMethodName(name) {
    if (BUILTIN_NAME_REG.test(name))
        return name;
    return `weda${name[0].toUpperCase()}${name.slice(1)}`;
}
exports.normalizeBuiltinMethodName = normalizeBuiltinMethodName;
function checkAuthOfMethod(params) {
    return weda_api_1.fetchWeda({
        action: 'AuthCustomMethod',
        data: {
            method: params.methodName,
            dataSourceName: params.dataSourceName,
        },
    }).then(res => res.Auth);
}
exports.checkAuthOfMethod = checkAuthOfMethod;
async function callBuiltinMethod(params, context) {
    try {
        if (params.useLegacy) {
            throw new utils_1.TCBError('ModelStop', 'should use legacy methods');
        }
        const data = await weda_api_1.fetchWeda({
            action: 'ProcessInternalMethod',
            data: {
                viewId: params.viewId,
                method: normalizeBuiltinMethodName(params.methodName),
                dataSourceName: params.dataSourceName,
                params: params.params || {},
            },
        }).then(res => res.Data);
        return { code: 0, data };
    }
    catch (error) {
        // 数据源内置方法调用失败时, 尝试原有实现
        if (error.code !== 'ModelStop')
            throw error;
        const normalizeFnName = fallback2oldMethodName(params.methodName);
        if (!database_1.default[normalizeFnName]) {
            throw new utils_1.TCBError(-1, `weda backend is out of service, ${params.methodName} not implements in legacy builtin methods`);
        }
        const res = await database_1.default[normalizeFnName](params.params, context);
        return {
            code: 0,
            data: res,
        };
    }
}
exports.callBuiltinMethod = callBuiltinMethod;
