"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getMethodCfg = exports.isMethodEnabled = void 0;
const builtin_method_1 = require("./builtin-method");
const http_method_1 = require("./http-method");
function isMethodEnabled(methodName, options, forceCall) {
    var _a;
    if (options.handlers[methodName])
        return true;
    if (!options.dsConfig)
        return false;
    const methodCfg = getMethodCfg(options.dsConfig, methodName);
    // 非内置数据源
    if (options.dsConfig.type !== 'database') {
        // http 方法
        if (methodCfg) {
            return !methodCfg.disabled && http_method_1.isHttpMethod(methodCfg);
        }
        return false;
    }
    if (!builtin_method_1.isBuiltinMethod(methodName))
        return false;
    // 强制调用, 直接返回 true
    if (forceCall)
        return true;
    const defaultMethods = ((_a = options.dsConfig.schema) === null || _a === void 0 ? void 0 : _a['x-defaultMethods']) || [];
    if (!defaultMethods.length)
        return false;
    // 用带前缀和不带前缀的都找一遍
    return defaultMethods.includes(methodName)
        || defaultMethods.includes(builtin_method_1.isNewBuiltinName(methodName)
            ? builtin_method_1.fallback2oldMethodName(methodName) : builtin_method_1.normalizeBuiltinMethodName(methodName));
}
exports.isMethodEnabled = isMethodEnabled;
/**
 * 获取方法配置描述
 */
function getMethodCfg(dsConfig, methodName) {
    if (dsConfig && Array.isArray(dsConfig.methods)) {
        return dsConfig.methods.find(item => (item === null || item === void 0 ? void 0 : item.name) === methodName);
    }
}
exports.getMethodCfg = getMethodCfg;
